import { __awaiter } from "tslib";
import { doc, getDoc, setDoc } from 'firebase/firestore';
import { delayedStore, } from './delayedStore';
import { disableClosingConfirmation, enableClosingConfirmation, mountClosingBehavior, } from '@telegram-apps/sdk';
export function createData(db, userGameInfo) {
    mountClosingBehavior.ifAvailable();
    disableClosingConfirmation.ifAvailable();
    const store = delayedStore(3000, saveData, (currentState) => {
        if (currentState === 'dirty') {
            enableClosingConfirmation.ifAvailable();
        }
        else {
            disableClosingConfirmation.ifAvailable();
        }
    });
    const userGameDataPath = `users/${userGameInfo.userId}/user-games-data/${userGameInfo.game}`;
    function saveUserData(payload) {
        return __awaiter(this, void 0, void 0, function* () {
            store.add(userGameDataPath, payload);
        });
    }
    function savePartData(docKey, payload) {
        return __awaiter(this, void 0, void 0, function* () {
            store.add(partPath(docKey), payload);
        });
    }
    function saveData(path, payload) {
        return __awaiter(this, void 0, void 0, function* () {
            const docRef = doc(db, path);
            yield setDoc(docRef, payload);
        });
    }
    function getUserData() {
        return __awaiter(this, void 0, void 0, function* () {
            const cachedData = readDataFromCache(userGameDataPath);
            if (cachedData) {
                return cachedData;
            }
            else {
                const docRef = doc(db, userGameDataPath);
                const snap = yield getDoc(docRef);
                return snap.data();
            }
        });
    }
    function readPartData(docKey) {
        return __awaiter(this, void 0, void 0, function* () {
            const dataPath = partPath(docKey);
            const cachedData = readDataFromCache(dataPath);
            if (cachedData) {
                return cachedData;
            }
            else {
                const partDoc = doc(db, dataPath);
                const snap = yield getDoc(partDoc);
                return snap.data();
            }
        });
    }
    function readDataFromCache(path) {
        if (store.getState() === 'dirty') {
            const cachedData = store.getData(path);
            if (cachedData) {
                return cachedData;
            }
        }
        return null;
    }
    const partPath = (docKey) => `${userGameDataPath}/parts/${docKey}`;
    return {
        saveUserData,
        getUserData,
        savePartData,
        readPartData,
        flush: store.flush,
    };
}
export function createFakeData(gameId) {
    return {
        saveUserData(payload) {
            try {
                localStorage.setItem(`${gameId}_data`, JSON.stringify(payload));
                return Promise.resolve();
            }
            catch (err) {
                return Promise.reject(err);
            }
        },
        getUserData() {
            const maybeData = localStorage.getItem(`${gameId}_data`);
            if (maybeData) {
                return Promise.resolve(JSON.parse(maybeData));
            }
            return Promise.resolve(undefined);
        },
        savePartData(docKey, payload) {
            try {
                localStorage.setItem(`${gameId}_data_part_${docKey}`, JSON.stringify(payload));
                return Promise.resolve();
            }
            catch (err) {
                return Promise.reject(err);
            }
        },
        readPartData(docKey) {
            const maybeData = localStorage.getItem(`${gameId}_data_part_${docKey}`);
            if (maybeData) {
                return Promise.resolve(JSON.parse(maybeData));
            }
            return Promise.resolve(undefined);
        },
        flush() {
            return __awaiter(this, void 0, void 0, function* () {
                console.debug('Fake persistence. Flush');
            });
        },
    };
}
//# sourceMappingURL=data.js.map