import { __awaiter } from "tslib";
import { initializeApp } from 'firebase/app';
import { createAuth, fakeAuth } from './auth/auth';
import { createP00lsBotApi } from './api/p00lsBotApi';
import { createData, createFakeData } from './data/data';
import { createAnalytics, fakeAnalytics } from './analytics/analytics';
import { isTMA, retrieveLaunchParams, retrieveRawInitData, } from '@telegram-apps/sdk';
import { createTelegram, fakeTelegram } from './telegram/telegram';
import { createFakePurchase, createPurchase } from './purchase/purchase';
import { createAds } from './ads';
import { createReferral, fakeReferral } from './referral/referral';
import { startClientTelemetry } from './telemetry/telemetry';
import { initializeFirestore, persistentLocalCache, persistentMultipleTabManager, } from 'firebase/firestore';
import { fakeAds } from './ads/fakeAds';
import { createStatistics, fakeStatistics } from './statistics/statistics';
import { createWallet, fakeWallet } from './wallet/wallet';
import { getConfig, isLocalSdkConfig } from './_config/config';
export function p00lsGamesSdk(configurationLocation) {
    return __awaiter(this, void 0, void 0, function* () {
        console.debug('Loading p00ls sdk');
        const inTMA = isTMA();
        console.debug('inTMA', inTMA);
        if (!inTMA) {
            console.debug('Not in TMA, returning fake SDK');
            return fakeSdk();
        }
        const config = yield getConfig(configurationLocation);
        const fbApp = initializeApp(config);
        if ((isLocalSdkConfig(config) && config.startTelemetryInLocalEnv) || inTMA) {
            startClientTelemetry({
                name: config.gameId,
                version: config.gameVersion || '',
                environment: config.env,
            });
        }
        console.debug('Init in TMA');
        return initInTMA(config, fbApp);
    });
}
function fakeSdk() {
    return {
        data: createFakeData('fakeGame'),
        auth: fakeAuth,
        analytics: fakeAnalytics,
        tma: fakeTelegram,
        purchase: createFakePurchase(),
        ads: fakeAds(fakeAnalytics.logEvent),
        referral: fakeReferral,
        statistics: fakeStatistics,
        wallet: fakeWallet,
    };
}
function isMobile(platform) {
    return platform.includes('ios') || platform.includes('android');
}
function shouldUseFullScreen(enabled, platform) {
    return (enabled || false) && isMobile(platform);
}
function initInTMA(config, fbApp) {
    return __awaiter(this, void 0, void 0, function* () {
        const debug = config.env !== 'prod';
        const { tgWebAppPlatform } = retrieveLaunchParams();
        const initDataRaw = retrieveRawInitData();
        const botApi = createP00lsBotApi(config);
        const auth = yield createAuth(initDataRaw || '', fbApp, botApi);
        const db = initializeFirestore(fbApp, {
            localCache: persistentLocalCache({
                tabManager: persistentMultipleTabManager(),
            }),
        });
        const data = createData(db, auth.userProfile);
        const tma = createTelegram(config.env, data.flush, shouldUseFullScreen(config.fullScreen, tgWebAppPlatform), !config.disableBackButton, isMobile(tgWebAppPlatform));
        const analytics = createAnalytics(fbApp, config.gameId, debug, auth.userProfile.userId, auth.trackingParameters);
        const ads = createAds({
            configuration: config.blockId
                ? { type: 'AdsGram', blockId: config.blockId }
                : config.adNetwork,
            debug,
            logEvent: analytics.logEvent,
        });
        const purchase = createPurchase(botApi, analytics.logEvent, auth.getIdToken);
        const referral = createReferral(db, botApi, auth.getIdToken, auth.userProfile, tma.share);
        const statistics = createStatistics(botApi, auth.getIdToken);
        statistics
            .changeDisplayName(auth.userProfile.username || auth.userProfile.firstName, false)
            .catch((err) => console.error('Error changing display name', err));
        const wallet = createWallet(config, botApi, auth.getIdToken);
        return {
            data,
            auth,
            analytics,
            tma,
            purchase,
            ads,
            referral,
            statistics,
            wallet,
        };
    });
}
//# sourceMappingURL=p00ls-games-sdk.js.map